@@ -38,9 +38,15 @@ QPixmap CScreenshotWidget::pixMap()
 
 void CScreenshotWidget::paintEvent(QPaintEvent *event)
 {
-    Q_UNUSED(event);
+    Q_UNUSED(event)
     QPainter painter(this);
     painter.drawPixmap(rect(), pixMap(), pixMap().rect());
+    QPoint centerPos = mapFromGlobal(QCursor::pos());
+    if (rect().contains(centerPos)) {
+        if (!_parentManager->_cursorPix.isNull())
+            painter.drawPixmap(QRect(centerPos - QPoint(_parentManager->_cursorPix.width() / 2, _parentManager->_cursorPix.height() / 2),
+                                     _parentManager->_cursorPix.size()), _parentManager->_cursorPix, _parentManager->_cursorPix.rect());
+    }
 }
 
 void CScreenshotWidget::keyPressEvent(QKeyEvent *event)
@@ -74,7 +80,7 @@ CPickerManager::CPickerManager(): QObject(nullptr)
     const int windowWidth = 236;
     qreal radio = qApp->devicePixelRatio();
     _shadowPixmap = QPixmap(Utils::getQrcPath("shadow.png"));
-    if (isSpcialPlatform()) {
+    if (isWaylandPlatform()) {
         _shadowPixmap = _shadowPixmap.scaled(windowWidth, windowHeight);
     } else {
         _shadowPixmap = _shadowPixmap.scaled(windowWidth / radio, windowHeight / radio, Qt::KeepAspectRatio, Qt::SmoothTransformation);
@@ -112,6 +118,11 @@ CPickerManager::CPickerManager(): QObject(nullptr)
     _updateScreenshotTimer = new QTimer(this);
     _updateScreenshotTimer->setSingleShot(true);
     connect(_updateScreenshotTimer, SIGNAL(timeout()), this, SLOT(handleMouseMove()));
+
+
+    QPixmap pix(16, 16);
+    pix.fill(Qt::transparent);
+    qApp->setOverrideCursor(QCursor(pix));
 }
 
 CPickerManager::~CPickerManager()
@@ -153,8 +164,18 @@ void CPickerManager::onMousePress(const QPoint &p, const int flag)
 {
     Q_UNUSED(p)
     int button = flag;
-    if (button != DRegionMonitor::Button_Left)
-        return;
+
+    if (isWaylandPlatform()) {
+        //wayland触摸屏下的点击是DRegionMonitor::Button_Middle，鼠标左键点击DRegionMonitor::Button_Left。无法区分是鼠标左键还是触摸屏，故支持中键点击
+        //最佳方案是TDK将触摸屏点击修改成左键点击。。。。。。。
+        if (button != DRegionMonitor::Button_Left && button != DRegionMonitor::Button_Middle) {
+            return;
+        }
+    } else {
+        if (button != DRegionMonitor::Button_Left)
+            return;
+    }
+
     //立即更新坐标
     _pos = p;
     handleMouseMove();
@@ -188,8 +209,18 @@ void CPickerManager::handleMouseMove()
 void CPickerManager::initShotScreenWidgets()
 {
     ensureDeskTopPixmap();
-
     auto screens = QApplication::screens();
+    //去出复制屏
+    int i = 0;
+    while (i < screens.size()) {
+        for (int j = screens.size() - 1; j > i; j--) {
+            if (screens.at(i)->geometry().topLeft() == screens.at(j)->geometry().topLeft()) {
+                screens.removeAt(j);
+            }
+        }
+        i++;
+    }
+
     foreach (auto screen, screens) {
         auto pix = getScreenShotPixmap(screen);
         //auto geometry = QRect(screen->geometry().topLeft(), screen->geometry().size() * screen->devicePixelRatio());
@@ -288,11 +319,9 @@ void CPickerManager::updateCursor(const QPixmap &pixMap, const QPoint &posInPixm
 //        painter.drawText(colorNameRect, text);
 
         //设置当前窗口鼠标样式
-        if (QApplication::overrideCursor() == nullptr) {
-            QApplication::setOverrideCursor(QCursor(cursorPix));
-        } else {
-            QApplication::changeOverrideCursor(QCursor(cursorPix));
-        }
+        _cursorPix = cursorPix;
+        this->autoUpdate();
+
     }
 }
 
@@ -308,7 +337,7 @@ void CPickerManager::ensureDeskTopPixmap()
 QPixmap CPickerManager::getScreenShotPixmap(QScreen *pScreen)
 {
     QPixmap result;
-    bool iswayLand = isSpcialPlatform();
+    bool iswayLand = isWaylandPlatform();
     if (iswayLand) {
         auto geometry = QRect(pScreen->geometry().topLeft(), pScreen->geometry().size() * pScreen->devicePixelRatio());
         result = _desktopPixmap.copy(geometry);
@@ -333,7 +362,7 @@ QRect getDeskTopRect()
 QPixmap CPickerManager::getDesktopPixmap()
 {
     QPixmap result;
-    bool iswayLand = isSpcialPlatform();
+    bool iswayLand = isWaylandPlatform();
     if (iswayLand) {
         QPixmap res;
         QDBusInterface kwinInterface(QStringLiteral("org.kde.KWin"),
@@ -363,7 +392,7 @@ QPixmap CPickerManager::getDesktopPixmap()
     return result;
 }
 
-bool CPickerManager::isSpcialPlatform()
+bool CPickerManager::isWaylandPlatform()
 {
     static auto e = QProcessEnvironment::systemEnvironment();
     static auto XDG_CURRENT_DESKTOP = e.value(QStringLiteral("XDG_CURRENT_DESKTOP"));
@@ -376,3 +405,26 @@ bool CPickerManager::isSpcialPlatform()
     return XDG_SESSION_TYPE == QLatin1String("wayland") ||
            WAYLAND_DISPLAY.contains(QLatin1String("wayland"), Qt::CaseInsensitive);
 }
+
+void CPickerManager::autoUpdate()
+{
+    if (nullptr == qApp->screenAt(QCursor::pos()))
+        return;
+
+    static QWidget *lastWidget = nullptr;
+    static QRect lastRect;
+    auto currentWidget = _widgets.value(qApp->screenAt(QCursor::pos()));
+
+    if (lastWidget != nullptr) {
+        lastWidget->update(lastRect);
+    }
+
+    if (currentWidget != nullptr) {
+        QRect currentRect = QRect(currentWidget->mapFromGlobal(QCursor::pos()) - QPoint(_cursorPix.width() / 2, _cursorPix.height() / 2), QSize(_cursorPix.size()));
+        if (lastWidget != currentWidget)
+            currentWidget->update(lastRect);
+        currentWidget->update(currentRect);
+        lastWidget = currentWidget;
+        lastRect = currentRect;
+    }
+}
